Learn R Programming

gamair (version 0.0-9)

chicago: Chicago air pollution and death rate data

Description

Daily air pollution and death rate data for Chicago.

Usage

data(chicago)

Arguments

Format

A data frame with 7 columns and 5114 rows. Each row refers to one day. The columns are:
  • death total deaths (per day).
  • pm10medianmedian particles in 2.5-10 per cubic m
  • pm25medianmedian particles < 2.5 mg per cubic m (more dangerous).
  • o3medianOzone in parts per billion
  • so2medianMedian Sulpher dioxide measurement
  • timetime in days
  • tmpdtemperature in fahrenheit

Roger D. Peng, Leah J. Welty and Aiden McDermott. R package NMMAPSdata.

Details

See the NMMAPSdata package for fuller details. Note that there are missing values in some fields.

References

Peng, R.D. and Welty, L.J. (2004) The NMMAPSdata package. R News 4(2).

Wood, S.N. (2006) Generalized Additive Models: An Introduction with R

http://www.ihapss.jhsph.edu/data/NMMAPS/R/