Data relating to the callibration of remote sensed satellite
data. The SeaWifs satellite provides estimates of chlorophyll concentration
at the ocean surface from measurements of ocean surface colour. It is of
interest to attempt to use these data to predict direct bottle measurements of
chl. conc.
Usage
data(chl)
Arguments
format
A data frame with 6 columns and 13840 rows. The columns are:
lon
{longitude}
lat{latitude}
jul.day{Julian day (i.e. day of year starting at Jan 1st.)}
bath{Ocean depth in metres.}
chl{direct chlorophyll concentration measured at given location from
a bottle sample.}
chl.sw{chl. conc. as measured by Seawifs Satellite}
source
http://seawifs.gsfc.nasa.gov/SEAWIFS
and the World Ocean Database.
References
Wood, S.N. (2006) Generalized Additive Models: An Introduction with R. CRC