Learn R Programming

gamair (version 0.0-9)

co2s: Atmospheric CO2 at South Pole

Description

Monthly CO2 concentration in parts per million at the South Pole.

Usage

data(co2s)

Arguments

Format

A data frame with 3 columns and 507 rows. The columns are:
  • co2atmospheric CO2 concentration in parts per million
  • c.monthcumulative number of months since Jan 1957
  • monthmonth of year

References

Keeling C.P. and T.P Whorf (2000) Atmospheric CO2 records from sites in the SIO air sampling network. In Trends: A Compedium of Data on Global Change. Carbon Dioxide Analyis Center, Oak Ridge National Laboratory, U.S. Department of Energy, Oak Ridge Tenn., USA

Wood, S.N. (2006) Generalized Additive Models: An Introduction with R. CRC

Examples

Run this code
  data(co2s)
  with(co2s,plot(c.month,co2,type="l",ylab=
  expression(paste(CO[2]," in ppm.")),xlab="Month since Jan. 1957"))

Run the code above in your browser using DataLab