Learn R Programming

gamair (version 0.0-7)

harrier: Hen Harriers Eating Grouse

Description

Data on the rate at which Hen Harriers consume Grouse as a function of Grouse density.

Usage

data(harrier)

Arguments

format

A data frame with 2 columns and 37 rows. The columns are:
  • Grouse.Density
{Density of Grouse per square kilometre.} Consumption.Rate{Number of Grouse consumed per Hen Harrier per day.}

source

Asseburg, C., S. Smout, J. Matthiopoulos, C. Fernandez, S. Redpath, S. Thirgood and J. Harwood (2005) The functional response of a generalist predator. Web preprint

Details

Data have been read from Figure 1 of Asseburg et al. (2005)

References

Wood, S.N. (2006) Generalized Additive Models: An Introduction with R. CRC

Examples

Run this code
data(harrier)
  with(harrier,plot(Grouse.Density,Consumption.Rate))

Run the code above in your browser using DataLab