A data frame with 5 columns. Each row corresponds to one spatial location within the survey area.
The columns are as follows:
{Longitude of the gridpoint in degrees east}- lat
{Latitude of the gridpoint in degrees north.}
- b.depth
{The sea bed depth at the gridpoint.}
- c.dist
{The distance from the gridpoint to the 200m sea bed depth contour.}
- salinity
{Salinity interpolated onto the grid (from mack measurements).}
- temp.surf
{Surface temperature interpolated onto grid (from mack data).}
- temp.20m
{Temperature at 20m interpolated from mack data.}
- area.index
{ An indexing vector that enables straightforward copying of
the other variables into a matrix suitable for plotting against longitude and
lattitude using image(). See the example below.}